#!/bin/sh
#
# nxtvepgd nexTView EPG decoder daemon
#
# chkconfig:   - 99 1
# description: Collects nexTView EPG data from a TV tuner card while it is \
#              not used by other applications.

### BEGIN INIT INFO
# Provides: nxtvepgd
# Required-Start: $local_fs $remote_fs $time zvbid
# Required-Stop: $local_fs $remote_fs $time
# Short-Description: nexTView EPG decoder daemon
# Description: Collects nexTView EPG data from a TV tuner card while it is
#              not used by other applications.
### END INIT INFO

# Source function library.
. /etc/rc.d/init.d/functions

exec="/usr/bin/nxtvepgd"
prog="nxtvepgd"
config="/etc/nxtvepgrc"
user="nxtvepg"
dbdir="/var/lib/nxtvepg"

[ -e /etc/sysconfig/$prog ] && . /etc/sysconfig/$prog

lockfile=/var/lock/subsys/$prog

start() {
    [ -x $exec ] || exit 5
    [ -f $config ] || exit 6
    echo -n $"Starting $prog: "
    daemon --user $user $exec -rcfile $config -dbdir $dbdir
    retval=$?
    echo
    [ $retval -eq 0 ] && touch $lockfile
    return $retval
}

stop() {
    echo -n $"Stopping $prog: "
    killproc $prog
    retval=$?
    echo
    [ $retval -eq 0 ] && rm -f $lockfile
    return $retval
}

restart() {
    stop
    start
}

reload() {
    restart
}

force_reload() {
    restart
}

rh_status() {
    # run checks to determine if the service is running or use generic status
    status $prog
}

rh_status_q() {
    rh_status >/dev/null 2>&1
}


case "$1" in
    start)
        rh_status_q && exit 0
        $1
        ;;
    stop)
        rh_status_q || exit 0
        $1
        ;;
    restart)
        $1
        ;;
    reload)
        rh_status_q || exit 7
        $1
        ;;
    force-reload)
        force_reload
        ;;
    status)
        rh_status
        ;;
    condrestart|try-restart)
        rh_status_q || exit 0
        restart
        ;;
    *)
        echo $"Usage: $0 {start|stop|status|restart|condrestart|try-restart|reload|force-reload}"
        exit 2
esac
exit $?

